.. _sunyaev-zeldovich:

Mock Observations of the Sunyaev-Zeldovich Effect
-------------------------------------------------

For an example of this functionality, see this
`sample notebook <https://github.com/yt-project/yt_astro_analysis/blob/master/doc/source/SZ_projections.ipynb>`__.
